==> medlogics-common-classes-1.1-20251205.144051-511.jar: com/floreantpos/model/dao/DocumentMetaDAO.java <==
package com.floreantpos.model.dao;

import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Restrictions;

import com.floreantpos.PosException;
import com.floreantpos.model.DocumentMeta;

public class DocumentMetaDAO extends BaseDocumentMetaDAO {

	/**
	 * Default constructor.  Can be used in place of getInstance()
	 */
	public DocumentMetaDAO() {
	}

	@Override
	public List<DocumentMeta> findAll() {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(DocumentMeta.class);
			addDeletedFilter(criteria);
			return criteria.list();
		}
	}

	@Override
	protected void delete(Object obj, Session session) {
		DocumentMeta documentMeta = (DocumentMeta) obj;
		if (documentMeta == null) {
			throw new PosException("Document meta data not found!");
		}

		documentMeta.setDeleted(Boolean.TRUE);
		saveOrUpdate(documentMeta, session);
	}

	/**
	 * Find all document metadata by entity
	 * @param entityModel the entity model type
	 * @param entityId the entity ID
	 * @return list of document metadata
	 */
	public List<DocumentMeta> findByEntity(String entityModel, String entityId) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(getReferenceClass());

			if (StringUtils.isNotBlank(entityModel)) {
				criteria.add(Restrictions.eq(DocumentMeta.PROP_ENTITY_MODEL, entityModel));
			}
			if (StringUtils.isNotBlank(entityId)) {
				criteria.add(Restrictions.eq(DocumentMeta.PROP_ENTITY_ID, entityId));
			}

			criteria.add(Restrictions.or(Restrictions.isNull(DocumentMeta.PROP_DELETED), Restrictions.eq(DocumentMeta.PROP_DELETED, false)));

			criteria.addOrder(Order.desc(DocumentMeta.PROP_PERFORM_DATE));

			return criteria.list();
		}
	}

	/**
	 * Find all document metadata by document ID
	 * @param documentId the document ID
	 * @return list of document metadata
	 */
	public List<DocumentMeta> findByDocumentId(String documentId) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(getReferenceClass());

			if (StringUtils.isNotBlank(documentId)) {
				criteria.add(Restrictions.eq(DocumentMeta.PROP_DOCUMENT_ID, documentId));
			}

			criteria.add(Restrictions.or(Restrictions.isNull(DocumentMeta.PROP_DELETED), Restrictions.eq(DocumentMeta.PROP_DELETED, false)));

			criteria.addOrder(Order.desc(DocumentMeta.PROP_PERFORM_DATE));

			return criteria.list();
		}
	}

}

==> medlogics-common-classes-1.1-20251211.143700-524.jar: com/floreantpos/model/dao/DocumentMetaDAO.java <==
package com.floreantpos.model.dao;

import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Restrictions;

import com.floreantpos.PosException;
import com.floreantpos.model.DocumentMeta;

public class DocumentMetaDAO extends BaseDocumentMetaDAO {

	/**
	 * Default constructor.  Can be used in place of getInstance()
	 */
	public DocumentMetaDAO() {
	}

	@Override
	public List<DocumentMeta> findAll() {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(DocumentMeta.class);
			addDeletedFilter(criteria);
			return criteria.list();
		}
	}

	@Override
	protected void delete(Object obj, Session session) {
		DocumentMeta documentMeta = (DocumentMeta) obj;
		if (documentMeta == null) {
			throw new PosException("Document meta data not found!");
		}

		documentMeta.setDeleted(Boolean.TRUE);
		saveOrUpdate(documentMeta, session);
	}

	/**
	 * Find all document metadata by entity
	 * @param entityModel the entity model type
	 * @param entityId the entity ID
	 * @return list of document metadata
	 */
	public List<DocumentMeta> findByEntity(String entityModel, String entityId) {
		return findByEntity(entityModel, entityId, null, null);
	}

	/**
	 * Find all document metadata by entity with optional search and type filter
	 * @param entityModel the entity model type
	 * @param entityId the entity ID
	 * @param searchText search text to filter by file name or description (optional)
	 * @param documentTypeName document type name to filter (optional)
	 * @return list of document metadata
	 */
	public List<DocumentMeta> findByEntity(String entityModel, String entityId, String searchText, String documentTypeName) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(getReferenceClass());

			if (StringUtils.isNotBlank(entityModel)) {
				criteria.add(Restrictions.eq(DocumentMeta.PROP_ENTITY_MODEL, entityModel));
			}
			if (StringUtils.isNotBlank(entityId)) {
				criteria.add(Restrictions.eq(DocumentMeta.PROP_ENTITY_ID, entityId));
			}

			// Filter by search text (file name or description)
			if (StringUtils.isNotBlank(searchText)) {
				String searchPattern = "%" + searchText.toLowerCase() + "%";
				criteria.add(Restrictions.or(
					Restrictions.ilike(DocumentMeta.PROP_FILE_NAME, searchPattern),
					Restrictions.ilike(DocumentMeta.PROP_DESCRIPTION, searchPattern)
				));
			}

			// Filter by document type
			if (StringUtils.isNotBlank(documentTypeName)) {
				criteria.add(Restrictions.eq(DocumentMeta.PROP_DOCUMENT_TYPE_NAME, documentTypeName));
			}

			criteria.add(Restrictions.or(Restrictions.isNull(DocumentMeta.PROP_DELETED), Restrictions.eq(DocumentMeta.PROP_DELETED, false)));

			criteria.addOrder(Order.desc(DocumentMeta.PROP_PERFORM_DATE));

			return criteria.list();
		}
	}

	/**
	 * Find all document metadata by document ID
	 * @param documentId the document ID
	 * @return list of document metadata
	 */
	public List<DocumentMeta> findByDocumentId(String documentId) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(getReferenceClass());

			if (StringUtils.isNotBlank(documentId)) {
				criteria.add(Restrictions.eq(DocumentMeta.PROP_DOCUMENT_ID, documentId));
			}

			criteria.add(Restrictions.or(Restrictions.isNull(DocumentMeta.PROP_DELETED), Restrictions.eq(DocumentMeta.PROP_DELETED, false)));

			criteria.addOrder(Order.desc(DocumentMeta.PROP_PERFORM_DATE));

			return criteria.list();
		}
	}

}
